@@ -5,7 +5,7 @@
 #include <sys/ioctl.h>
 #include <sys/types.h>
 #include <sys/socket.h>
-#include <linux/atm.h>
+#include <atm.h>
 #include <linux/atmdev.h>
 #include <linux/sonet.h>
 #include <linux/atm_eni.h>
