@@ -35,10 +35,21 @@
 
 AsnOid atmfPortIndex = {13, "\53\06\01\04\01\202\141\02\01\01\01\01\00"};
 AsnOid atmfMyIpNmAddress = {11, "\53\06\01\04\01\202\141\02\01\02\00"};
+AsnOid atmfAtmLayerUniVersion =  {13,        "\53\06\01\04\01\202\141\02\02\01\01\11\00"};
 AsnOid atmfNetPrefixStatus = {NETPREFIX_LEN, "\53\06\01\04\01\202\141\02\07\01\01\03"};
 
 AsnInt atmfPortIndexValue = 0;
-AsnOid atmfMyIpNmAddressValue = {4 , "\0\0\0\0"};
+IpAddress atmfMyIpNmAddressValue = {4 , NULL};
+
+#ifdef UNI40
+AsnInt atmfAtmLayerUniVersionValue = 4;		// version4point0(4)
+#else
+#if defined(UNI31) 
+AsnInt atmfAtmLayerUniVersionValue = 3;		// version3point1(3)
+#else
+AsnInt atmfAtmLayerUniVersionValue = 2;		// version3point0(2)
+#endif
+#endif
 
 static AsnOid atmNetPrefix = {0, NULL};
 
@@ -174,9 +185,3 @@ AsnInt setNetPrefix(VarBind *varbind, Variable *var)
 
   return NOERROR;
 }
-
-
-
-
-
-
