@@ -154,6 +154,10 @@ main(int argc, char **argv)
       exit(-1);
     }
   }
+  if (argc != optind) {
+    usage(argv[0]);
+    exit(-1);
+  }
   /* Following gets run in the beginning or when lecs is restarted */
   while (stay_alive) {
 
