@@ -65,6 +65,10 @@
 #define  LE_FLAG_REMOTE_ADDR     0x0001
 #define  LE_FLAG_PROXY           0x0080
 #define  LE_FLAG_TOPOLOGY_CHANGE 0x0100
+#define  LE_FLAG_V2_CAPABLE      0x0002        /* LANE2 */
+#define  LE_FLAG_SELECTIVE_MCAST 0x0004        /* LANE2 */
+#define  LE_FLAG_V2_REQUIRED     0x0008        /* LANE2 */
+#define  LE_FLAG_TOKEN_RING_EE   0x0200        /* LANE2 */
 
 /*
  * Control Frame Status Definitions
@@ -82,6 +86,7 @@
 #define  LE_STATUS_NO_CONFIG             20
 #define  LE_STATUS_LE_CONFIG_ERROR       21
 #define  LE_STATUS_INSUFFICIENT_INFO     22
+#define  LE_STATUS_TLV_NOT_FOUND         24    /* LANE2 */
 
 /*
  * Control Frame Op-Codes
@@ -102,6 +107,8 @@
 #define  LE_FLUSH_RSP      0x0107
 #define  LE_NARP_REQ       0x0008
 #define  LE_TOPOLOGY_REQ   0x0009
+#define  LE_VERIFY_REQ     0x000a    /* LANE2 */
+#define  LE_VERIFY_RSP     0x010a    /* LANE2 */
 
 /*
  * TLV Types
@@ -121,6 +128,13 @@
 #define  TLV_MCAST_VCC_AVG_RATE        0x00a03e0d
 #define  TLV_MCAST_VCC_PEAK_RATE       0x00a03e0e
 #define  TLV_CONNECT_COMPLETION_TIMER  0x00a03e0f
+#define  TLV_X5_ADJUSTEMENT            0x00a03e2c /* LANE2 TLVs from here */
+#define  TLV_L3_ADDRESS                0x00a03e11
+#define  TLV_ELAN_ID                   0x00a03e12
+#define  TLV_PREFERRED_LES             0x00a03e2d
+#define  TLV_SERVICE_CATEGORY          0x00a03e13
+#define  TLV_LLC_MUXED_ATM_ADDRESS     0x00a03e2b
+#define  TLV_CONFIG_FRAG_INFO          0x00a03e10
 
 /* Definitions for BLLI codepoint values in signaled VCCs. */
 
@@ -244,11 +258,27 @@ typedef struct
    LE_LAN_DST     src_lan_dst;
    LE_LAN_DST     target_lan_dst;
    ADDR_ATM       src_atm_addr;
-   UINT32         reserved1;
+     /*   UINT32         reserved1; */ /* lane 1 version */
+   UINT16         reserved1;
+   UINT8          tlv_count; /* LANE2: tlv_count added */
+   UINT8          reserved3;
    ADDR_ATM       target_atm_addr;
    UINT32         reserved2[8];
    } LE_ARP_FRAME;
 
+typedef struct /* this is the LANE2 version */
+   {
+   LE_CTRL_HDR    hdr;
+   LE_LAN_DST     src_lan_dst;
+   LE_LAN_DST     target_lan_dst;
+   ADDR_ATM       src_atm_addr;
+   UINT16         reserved;
+   UINT8          tlv_count;
+   UINT8          reserved2;
+   ADDR_ATM       target_atm_addr;
+   UINT32         reserved3[8];
+   } LE_NARP_FRAME;
+
 typedef struct
    {
    LE_CTRL_HDR    hdr;
