@@ -1,6 +1,6 @@
 /* misc.c - Miscellaneous library functions */
 
-/* Written 1997,1998 by Werner Almesberger, EPFL-ICA */
+/* Written 1997,1998 by Werner Almesberger, EPFL-ICA/ICA */
 
 
 #include <stdint.h>
@@ -9,7 +9,6 @@
 #include <sys/socket.h>
 #include <sys/ioctl.h>
 #include <netinet/in.h> /* for htons */
-#include <linux/atm.h>
 
 #include <atm.h>
 #include <atmsap.h>
