@@ -9,7 +9,7 @@ int send_to_mps(char *buff, int length);
 int send_to_dataplane(char *buff, int length, int fd);
 void keep_alive_sm(unsigned keep_alive_lifetime, int sequence_number);
 int get_socket(struct sockaddr_atmsvc *address);
-void create_ingress_svc(uint32_t ipaddr, char *atm_addr);
+void create_ingress_svc(uint32_t ipaddr, char *atm_addr, struct atm_qos qos);
 
 /* Socket types and states */
 #define NOT_USED          0x0000
