@@ -28,6 +28,8 @@ static void snd_mpoa_res_rqst(struct k_message *msg);
 static void snd_mpoa_res_rtry(struct k_message *msg);
 static void set_mps_ctrl_addr(struct k_message *msg);
 static void stop_keep_alive_sm(void);
+static uint32_t traff_class_to_service_category(uint8_t traffic_class);
+
 /*
  * returns < 0 for error
  *
@@ -109,7 +111,8 @@ int msg_from_kernel(int fd)
 	case OPEN_INGRESS_SVC:
 	        dprintf(" open_ingress_svc");
 		create_ingress_svc(msg.content.in_info.in_dst_ip,
-				   msg.content.in_info.eg_MPC_ATM_addr);
+				   msg.content.in_info.eg_MPC_ATM_addr,
+				   msg.qos);
 		return 1;
 		break;
         default:
@@ -125,7 +128,7 @@ static void snd_mpoa_res_rqst(struct k_message *msg){
 				1,                      /* Source ip present */ 
 				msg->content.in_info.in_dst_ip,
 				0,                      /* prefix length */
-				msg->content.in_info.service_category);
+				traff_class_to_service_category(msg->qos.txtp.traffic_class));
 
          return;
 }
@@ -137,7 +140,7 @@ static void snd_mpoa_res_rtry(struct k_message *msg){
 				1,              
 				msg->content.in_info.in_dst_ip,
 				0,              
-				msg->content.in_info.service_category);
+				traff_class_to_service_category(msg->qos.txtp.traffic_class));
 
          return;
 }
@@ -176,4 +179,23 @@ static void stop_keep_alive_sm(){
   return;
 }
 
+/* 
+ * Converts linux-ATM traffic descriptions to those used in MPOA ATM service 
+ * category extension. Only UBR and CBR supported.
+ */
+static uint32_t traff_class_to_service_category(uint8_t traffic_class){
+  switch(traffic_class){
+  case ATM_NONE:
+    return 0;
+    break;
+  case ATM_UBR:
+    return 0;
+    break;
+  case ATM_CBR:
+    return CBR;
+    break;
+  default:
+    return 0;
+  }
+}
 
