@@ -434,7 +434,13 @@ int main(int argc,char **argv)
     init_current_time();
     if (mode != sm_switch) init_addr();
     q_start();
-    start_saal(&saal,&ops,NULL);
+    start_saal(&saal,&ops,NULL,
+#ifdef UNI30
+      sscop_qsaal1
+#else
+      sscop_q2110
+#endif
+      );
     saal_estab_req(&saal,NULL,0);
     setup_signals();
     if (background) {
