@@ -115,14 +115,16 @@ static int send_connect(SOCKET *sock)
     q_assign(&dsc,QF_msg_type,ATM_MSG_CONNECT);
     q_assign(&dsc,QF_call_ref,sock->call_ref);
     if (sock->ep_ref >= 0) q_assign(&dsc,QF_ep_ref,sock->ep_ref);
-    q_assign(&dsc,QF_aal_type,5);
+    if (sock->ep_ref <= 0) { /* no AAL parameters if ep_ref present and != 0 */
+	q_assign(&dsc,QF_aal_type,5);
 #ifdef UNI30
-    q_assign(&dsc,QF_aal_mode,1); /* Message mode - LANE seems to really want
-				     this */
+	q_assign(&dsc,QF_aal_mode,1); /* Message mode - LANE seems to really
+					 want this */
 #endif
-    q_assign(&dsc,QF_sscs_type,0); /* unspecified - LANE wants this */
-    q_assign(&dsc,QF_fw_max_sdu,sock->qos.rxtp.max_sdu);
-    q_assign(&dsc,QF_bw_max_sdu,sock->qos.txtp.max_sdu);
+	q_assign(&dsc,QF_sscs_type,0); /* unspecified - LANE wants this */
+	q_assign(&dsc,QF_fw_max_sdu,sock->qos.rxtp.max_sdu);
+	q_assign(&dsc,QF_bw_max_sdu,sock->qos.txtp.max_sdu);
+    }
     if ((size = q_close(&dsc)) >= 0) to_signaling(q_buffer,size);
     return 0;
 }
